@@ -9,12 +9,13 @@ class AverageListDialog : public ListDialog
 {
 	Q_OBJECT
 public:
-	AverageListDialog(Worksheet *p, const char *name);
-private slots:
-	void ok_clicked() { apply_clicked(); accept(); }
-	void apply_clicked();
+	AverageListDialog(MainWin *mw, const char *name);
+public slots:
+	void setN(int n) { nle->setText(QString::number(n)); }		//!< set number of points to average
 private:
 	KLineEdit *nle;
+private slots:
+	int apply_clicked();
 };
 
 #endif // AVERAGELISTDIALOG_H
