@@ -15,31 +15,30 @@ class AxesDialog: public Dialog
 {
 	Q_OBJECT
 public:
-	AxesDialog(Worksheet *p, const char *name, int axesnr);
+	AxesDialog(MainWin *mw, const char *name, int axesnr);
 public slots:
 	void selectTicsFont();
-	void setTicsColor(const QColor &color) { tc = QColor(color); }
-	void setTicsLabelColor(const QColor &color) { tlc = QColor(color); }
-	void setGridColor(const QColor &color) { gc = QColor(color); }
-	void setBorderColor(const QColor &color) { bc = QColor(color); }
 	void updateAxis();
 	void update_timeformat();
 	void updateScale(int i);
 	void axisEnabled(bool on);
-	void ok_clicked();
+	void ok_clicked() { apply_clicked(); accept(); }
 	void apply_clicked();
 private:
 	Plot *plot;
+	Axis *axis[12];
 	int type;
 	RichTextWidget *rtw;
-	KLineEdit *scaling, *shift, *ticsfont, *min, *max, *major, *minor, *tlple;
+	KLineEdit *scaling, *shift, *ticsfont, *min, *max, *major, *minor, *tlple, *tlgle;
 	KLineEdit *tlprefix, *tlsuffix, *timeformat, *tlrotation;
 	KListBox *axeslb;
 	QCheckBox *cb, *cb2, *cb3, *cb4, *cb5, *cb6;
+	KLineEdit *majorticswidthle, *minorticswidthle, *borderwidthle, *majorgridwidthle, *minorgridwidthle;
+	KLineEdit *majorticslengthle, *minorticslengthle;
 	KColorButton *tcb, *tlcb, *gcb, *bcb;
 	KComboBox *atlfcb, *ascb, *ticsposcb;
 	QFont tf;
-	QColor tc, tlc, gc, bc;
-	Axis *axis[12];
+	KComboBox *majorgridstylecb, *minorgridstylecb;
+	KColorButton *majorgridcolorcb, *minorgridcolorcb;
 };
 #endif //AXESDIALOG_H
