@@ -2,13 +2,13 @@
 
 #include "Axis.h"
 
-/*! general axis class */
+//! general axis class
 Axis::Axis() {
 	l = new Label();
 	scale = LINEAR;
 	scaling=1;
 	shift=0;
-	e = TRUE;
+	e = true;
 	tlrotation=0;
 	tlprefix=QString("");
 	tlsuffix=QString("");
@@ -16,14 +16,21 @@ Axis::Axis() {
 	tc = QColor("black");
 	tlc = QColor("black");
 	bc = QColor("black");
-	gc = QColor("black");
-	majortics = 5;
+	minorgridcolor = QColor("black");
+	majorgridcolor = QColor("black");
+	majortics = -1;		// default ("auto")
 	minortics = 3;
-	majorticse = TRUE;
-	minorticse = TRUE;
+	majorticse = true;
+	minorticse = true;
 	atlf = AUTO;
 	datetimeformat = "auto";
 	tlp = 2;
 	ticspos = 0;
+	gap = 15;
+	majorgridtype = Qt::DashLine;
+	minorgridtype = Qt::DotLine;
+	majorticswidth = minorticswidth = 1;
+	borderwidth = 1;
+	majorgridwidth = minorgridwidth = 1;
 }
 
