@@ -9,11 +9,10 @@ class DifferencesListDialog : public ListDialog
 {
 	Q_OBJECT
 public:
-	DifferencesListDialog(Worksheet *p, const char *name);
+	DifferencesListDialog(MainWin *mw, const char *name);
+public slots:
 private slots:
-	void ok_clicked() { apply_clicked(); accept(); }
-	void apply_clicked();
-private:
+	int apply_clicked();
 };
 
 #endif // DIFFERENCESLISTDIALOG_H
