@@ -19,11 +19,17 @@ public:
 	Point endPoint() { return end; }
 	void setStartPoint(double x, double y) { start=Point(x,y);}
 	void setEndPoint(double x, double y) { end=Point(x,y);}
-	int getWidth() { return width; }
-	QColor getColor() { return color; }
-	QColor getFillColor() { return fill; }
-	void draw(QPainter *p, double w, double h);
+	int Width() { return width; }
+	void setWidth(int w) { width=w; }
+	QColor Color() { return color; }
+	void setColor(QColor c) { color=c; }
+	void setColor(QString c) { color=QColor(c); }
+	QColor FillColor() { return fill; }
+	void setFillColor(QColor c) { fill=c; }
+	void setFillColor(QString c) { fill=QColor(c); }
 	bool isFilled() { return filled; }
+	void setFilled(bool f=true) { filled=f; }
+	void draw(QPainter *p, int w, int h);
 	bool inside(int x, int y, int w, int h);
 protected:
 	Point start, end;	// start = left upper corner, end = (width,height)
