@@ -13,15 +13,11 @@ class ExplorerDialog: public Dialog
 {
 	Q_OBJECT
 public:
-	ExplorerDialog(Worksheet *p, const char *name);
-public slots:
-//	void ok_clicked() { apply_clicked(); accept(); }
-//	void apply_clicked();
+	ExplorerDialog(MainWin *mw, const char *name);
 private slots:
 	void initlist();
 	void rmouse(QListViewItem *item, const QPoint & point, int );
 private:
-	MainWin *mw;
 	QListView *lv;
 	QPopupMenu *menu;
 };
