@@ -4,30 +4,30 @@
 #define GRAPH3D_H
 
 #include <qtextstream.h>
+#include <qprogressdialog.h>
 #include "Graph.h"
 #include "LRange.h"
 #include "Point3D.h"
-#include "defs.h"
 
 class Graph3D: public Graph
 {
 public:
-	Graph3D(QString n=QString(""), QString l=QString(""), LRange r[3]=0, int t=P3D, 
-		Style st=Style(), Symbol sy=Symbol(), Point3D *p=0, int nrx=0, int nry=0, bool s=TRUE);
-	Point3D *getData() { return ptr; }
-	LRange getRange(int i) { return range[i]; }
+	Graph3D(QString n=QString(""), QString l=QString(""), LRange r[3]=0, LSource src=SFUNCTION, PType t=P3D, 
+		Style *st=0, Symbol *sy=0, Point3D *p=0, int nrx=0, int nry=0, bool s=true);
+	Point3D *Data() { return ptr; }
+	LRange Range(int i) { return range[i]; }
 	void setRange(LRange *r) { range[0]=r[0];range[1]=r[1];range[2]=r[2]; }
-	int Number() { return number; }
 	int NX() { return numberx; }
 	int NY() { return numbery; }
 	void setNumber(int n) { number = n; }
 	void setNumberX(int n) { numberx = n; }
 	void setNumberY(int n) { numbery = n; }
-	void save(QTextStream *t);
-	void open(QTextStream *t,int version);
+	void save(QTextStream *t, QProgressDialog *progress);
+	void open(QTextStream *t,int version, QProgressDialog *progress);
 	QStringList Info();
+	LRange ErrorDYRange();
 private:
-	int number, numberx, numbery;
+	int numberx, numbery;
 	Point3D *ptr;
 	LRange *range;
 };
