@@ -9,10 +9,12 @@ class GraphListDialog : public ListDialog
 {
 	Q_OBJECT
 public:
-	GraphListDialog(Worksheet *p, const char *name);
+	GraphListDialog(class MainWin *mw, const char *name=0);
 public slots:
 	void newData();
 	void newFunction();
+	
+	int apply_clicked() { return 0; }	// virtual
 private:
 	Plot *plot;		// active plot
 };
