@@ -5,22 +5,22 @@
 
 #include <qfont.h>
 #include <qcheckbox.h>
-#include "Worksheet.h"
+#include "MainWin.h"
 #include "Dialog.h"
 
 class ImageMagickDialog: public Dialog
 {
 	Q_OBJECT
 public:
-	ImageMagickDialog(Worksheet *p, const char *name);
+	ImageMagickDialog(MainWin *mw, QString fn=i18n("out.8bim"), int f=0, int sx=800, int sy=600,
+		double r=0.0, const char *name=0);
 public slots:
-	void ok_clicked() { apply_clicked(); accept(); }
+	void Apply() { apply_clicked(); accept(); }
 	void apply_clicked();
 private slots:
 	void selectFile();
 	void updateFilename(int index);
 private:
-	Worksheet *p;
 	QStringList formats;
 	KComboBox *format;
 	KLineEdit *filele, *xle, *yle, *rotle;
