@@ -11,34 +11,40 @@ using namespace std;
 Plot3D::Plot3D(Worksheet *p)
 	: Plot(p) 
 {
-	title = new Label(i18n("Title 3D"),QFont("Adobe Times",22),QColor(Qt::black));
+	QFont font = p->getMainWin()->defaultFont();
+	font.setPointSize((int)(0.7*font.pointSize()));	// for axes label
+	title = new Label(i18n("Title 3D"),font,QColor(Qt::black));
 	title->setPosition(0.4,0.04);
 
-	axis[0].setLabel(new Label(i18n("x-Axis")));
-	axis[1].setLabel(new Label(i18n("y-Axis")));
-	axis[2].setLabel(new Label(i18n("z-Axis")));
-	axis[3].setLabel(new Label(i18n("x2-Axis")));
-	axis[4].setLabel(new Label(i18n("y2-Axis")));
-	axis[5].setLabel(new Label(i18n("z2-Axis")));
-	axis[6].setLabel(new Label(i18n("x3-Axis")));
-	axis[7].setLabel(new Label(i18n("y3-Axis")));
-	axis[8].setLabel(new Label(i18n("z3-Axis")));
-	axis[9].setLabel(new Label(i18n("x4-Axis")));
-	axis[10].setLabel(new Label(i18n("y4-Axis")));
-	axis[11].setLabel(new Label(i18n("z4-Axis")));
+	axis[0].setLabel(new Label(i18n("x-Axis"),font));
+	axis[1].setLabel(new Label(i18n("y-Axis"),font));
+	axis[2].setLabel(new Label(i18n("z-Axis"),font));
+	axis[3].setLabel(new Label(i18n("x2-Axis"),font));
+	axis[4].setLabel(new Label(i18n("y2-Axis"),font));
+	axis[5].setLabel(new Label(i18n("z2-Axis"),font));
+	axis[6].setLabel(new Label(i18n("x3-Axis"),font));
+	axis[7].setLabel(new Label(i18n("y3-Axis"),font));
+	axis[8].setLabel(new Label(i18n("z3-Axis"),font));
+	axis[9].setLabel(new Label(i18n("x4-Axis"),font));
+	axis[10].setLabel(new Label(i18n("y4-Axis"),font));
+	axis[11].setLabel(new Label(i18n("z4-Axis"),font));
 
 	// grid & border
+	font.setPointSize((int)(0.7*font.pointSize()));	// for tic label
+
 	for (int i=0;i<12;i++) {
-		borderenabled[i] = TRUE;
+		borderenabled[i] = true;
 		axis[i].enable(1);
+		axis[i].setTicsFont(font);
 	}
 	for (int i=3;i<12;i++)
 		axis[i].enable(0);
 	for (int i=0;i<24;i++)
-		gridenabled[i] = FALSE;
+		gridenabled[i] = false;
 }
 
 QStringList Plot3D::Info() {
+	kdDebug()<<"Plot3D::Info()"<<endl;
 	QStringList s;
 	s<<"3D";
 	s<<QString::number(position.X())+QString(" , ")+QString::number(position.Y());
@@ -54,6 +60,7 @@ QStringList Plot3D::Info() {
 }
 
 void Plot3D::setBorder(int item, bool on) {
+	kdDebug()<<"Plot3D::setBorder() : item="<<item<<endl;
 	const int unit = 5, numunit = 40, numunit2 = 20;
 	int w = worksheet->width(), h = worksheet->height();
 
@@ -64,51 +71,51 @@ void Plot3D::setBorder(int item, bool on) {
 
 	if(item == 3) {
 		if (on) {
-			if (axis[3].label()->title().length() > 0) ymax -= axis[3].label()->font().pointSize();
-			if (axis[3].majorTicsEnabled())   ymax -= unit+numunit2;
-			if (axis[3].minorTicsEnabled())   ymax -= unit;
+			if (axis[3].label()->Title().length() > 0) ymax -= axis[3].label()->Font().pointSize();
+			if (axis[3].MajorTicsEnabled())   ymax -= unit+numunit2;
+			if (axis[3].MinorTicsEnabled())   ymax -= unit;
 		}
 		else {
-			if (axis[3].label()->title().length() > 0) ymax += axis[3].label()->font().pointSize();
-			if (axis[3].majorTicsEnabled())   ymax += unit+numunit2;
-			if (axis[3].minorTicsEnabled())   ymax += unit;
+			if (axis[3].label()->Title().length() > 0) ymax += axis[3].label()->Font().pointSize();
+			if (axis[3].MajorTicsEnabled())   ymax += unit+numunit2;
+			if (axis[3].MinorTicsEnabled())   ymax += unit;
 
 		}
 	}
 	if(item == 5) {
 		if (on) {
-			if (axis[5].label()->title().length() > 0) xmin += axis[5].label()->font().pointSize();
-			if (axis[5].majorTicsEnabled())   xmin += unit+numunit;
-			if (axis[5].minorTicsEnabled())   xmin += unit;
+			if (axis[5].label()->Title().length() > 0) xmin += axis[5].label()->Font().pointSize();
+			if (axis[5].MajorTicsEnabled())   xmin += unit+numunit;
+			if (axis[5].MinorTicsEnabled())   xmin += unit;
 		}
 		else {
-			if (axis[5].label()->title().length() > 0) xmin -= axis[5].label()->font().pointSize();
-			if (axis[5].majorTicsEnabled())   xmin -= unit+numunit;
-			if (axis[5].minorTicsEnabled())   xmin -= unit;
+			if (axis[5].label()->Title().length() > 0) xmin -= axis[5].label()->Font().pointSize();
+			if (axis[5].MajorTicsEnabled())   xmin -= unit+numunit;
+			if (axis[5].MinorTicsEnabled())   xmin -= unit;
 		}
 	}
 	if(item == 9) {
 		if (on) {
-			if (axis[9].label()->title().length() > 0) ymin += axis[9].label()->font().pointSize();
-			if (axis[9].majorTicsEnabled())   ymin += unit+numunit2;
-			if (axis[9].minorTicsEnabled())   ymin += unit;
+			if (axis[9].label()->Title().length() > 0) ymin += axis[9].label()->Font().pointSize();
+			if (axis[9].MajorTicsEnabled())   ymin += unit+numunit2;
+			if (axis[9].MinorTicsEnabled())   ymin += unit;
 		}
 		else {
-			if (axis[9].label()->title().length() > 0) ymin += axis[9].label()->font().pointSize();
-			if (axis[9].majorTicsEnabled())   ymin += unit+numunit2;
-			if (axis[9].minorTicsEnabled())   ymin += unit;
+			if (axis[9].label()->Title().length() > 0) ymin += axis[9].label()->Font().pointSize();
+			if (axis[9].MajorTicsEnabled())   ymin += unit+numunit2;
+			if (axis[9].MinorTicsEnabled())   ymin += unit;
 		}
 	}
 	if(item == 11) {
 		if (on) {
-			if (axis[11].label()->title().length() > 0) xmax -= axis[11].label()->font().pointSize();
-			if (axis[11].majorTicsEnabled())   xmax -= unit+numunit;
-			if (axis[11].minorTicsEnabled())   xmax -= unit;
+			if (axis[11].label()->Title().length() > 0) xmax -= axis[11].label()->Font().pointSize();
+			if (axis[11].MajorTicsEnabled())   xmax -= unit+numunit;
+			if (axis[11].MinorTicsEnabled())   xmax -= unit;
 		}
 		else {
-			if (axis[11].label()->title().length() > 0) xmax += axis[11].label()->font().pointSize();
-			if (axis[11].majorTicsEnabled())   xmax += unit+numunit;
-			if (axis[11].minorTicsEnabled())   xmax += unit;
+			if (axis[11].label()->Title().length() > 0) xmax += axis[11].label()->Font().pointSize();
+			if (axis[11].MajorTicsEnabled())   xmax += unit+numunit;
+			if (axis[11].MinorTicsEnabled())   xmax += unit;
 		}
 	}
 
@@ -119,9 +126,8 @@ void Plot3D::setBorder(int item, bool on) {
 }
 
 void Plot3D::draw(QPainter *p,int w, int h) {
-	//int w = worksheet->width(), h = worksheet->height();
-
 	kdDebug()<<"Plot3D::draw() w/h : "<<w<<' '<<h<<endl;
+
 	int xmin = (int)(w*(size.X()*p1.X()+position.X()));
 	int xmax = (int)(w*(size.X()*p2.X()+position.X()));
 	int ymin = (int)(h*(size.Y()*p1.Y()+position.Y()));
@@ -152,12 +158,13 @@ void Plot3D::draw(QPainter *p,int w, int h) {
 		(xmax+xmin)/2,ymin-(ymax-ymin)/2,xmin,ymin);
 	p->drawPolygon(a);
 
-        // TODO : draw baseline here (before every axis ?) -> see Plot2D.cc
+        // TODO : draw y baseline here (before every axis ?) -> see Plot2D.cc
+        // TODO : draw x baseline here (before every axis ?) -> see Plot2D.cc
 
 	// TODO
 	kdDebug()<<"PLOT3D : title->draw() pos:"<<position.X()<<' '<<position.Y()<<endl;
 	kdDebug()<<" 			size:"<<size.X()<<' '<<size.Y()<<endl;
-	title->draw(p,position,size,w,h);
+	title->draw(worksheet,p,position,size,w,h,0);
 
 	drawAxes(p,w,h,0);	// all axes & borders
 	drawBorder(p,w,h,0);
@@ -169,9 +176,13 @@ void Plot3D::draw(QPainter *p,int w, int h) {
 
 	if(legend.enabled())
 		legend.draw(p,type,graphlist,position,size,w,h);
+
+	p->setPen(Qt::NoPen);
 }
 
 void Plot3D::drawBorder(QPainter *p,int w, int h,bool hide) {
+	kdDebug()<<"Plot3D::drawBorder()"<<endl;
+	// TODO : borderwidth
 	int start=0;
 	if (hide) start=3;
 
@@ -195,7 +206,7 @@ void Plot3D::drawBorder(QPainter *p,int w, int h,bool hide) {
 
 	for (int i=start;i<12;i++) {
 		if (borderenabled[i]) {
-			p->setPen(axis[i].borderColor());
+			p->setPen(QPen(axis[i].BorderColor(),axis[i].borderWidth()));
 			p->drawLine(x1[i],y1[i],x2[i],y2[i]);
 		}
 	}
@@ -215,38 +226,42 @@ void Plot3D::drawCurves(QPainter *p, int w, int h) {
 	kdDebug()<<"xmin/xmax ymin/ymax : "<<xmin<<'/'<<xmax<<' '<<ymin<<'/'<<ymax<<endl;
 	kdDebug()<<"width/height : "<<w<<'/'<<h<<endl;
 
-	for (unsigned int i=0; i < graphlist->getNumber() ; i++) {
-		if(graphlist->getGraph(i)->isShown() == FALSE)
+	for (unsigned int i=0; i < graphlist->Number() ; i++) {
+		kdDebug()<<"draw Graph "<<i+1<<endl;
+		if(graphlist->getGraph(i)->isShown() == false)
 			continue;
 		
 		double oldx=0, oldy=0;
 		double oldlinex=0, oldliney=0;
 		int N, NY=0, NX=0;
-		Style style;
-		Symbol symbol;
+		Style *style=0;
+		Symbol *symbol=0;
 		GRAPHType s = graphlist->getStruct(i);
 		Graph *graph=graphlist->getGraph(i);
 		Point3D *d=0;
 		if (s == GRAPH3D) {
+			kdDebug()<<"GRAPH3D "<<endl;
 			Graph3D *g = graphlist->getGraph3D(i);
 
-			d = g->getData();
+			d = g->Data();
 			NX=g->NX();
 			NY=g->NY();
 			style =  g->getStyle();
 			symbol = g->getSymbol();
+			kdDebug()<<" ... OK "<<endl;
 		}
 		else if (s == GRAPHM) {
 			GraphM *g = graphlist->getGraphM(i);
 
-			double *data = g->getData();
+			double *data = g->Data();
 			NX=g->NX();
 			NY=g->NY();
+			kdDebug()<<"GRAPHM "<<NX<<'x'<<NY<<endl;
 			// conversion to 3d Point data
 			d = new Point3D[NX*NY];
-			for (int j=0;j<NX;j++) {
-				for (int k=0;k<NY;k++) {
-					d[k+j*NX].setPoint(j+1,k+1,data[k+j*NX]);
+			for (int j=0;j<NY;j++) {
+				for (int k=0;k<NX;k++) {
+					d[k+j*NX].setPoint(k+1,j+1,data[k+j*NX]);
 				}
 			}
 			style =  g->getStyle();
@@ -257,36 +272,53 @@ void Plot3D::drawCurves(QPainter *p, int w, int h) {
 		else
 			N=NX*NY;
 
-		int type = style.Type();
+		int type = style->Type();
 
 		double *linex = new double[NX], *liney = new double[NX];	// NX is ok here
-//		for (int k=0; k<NY;k++) {
 		for (int k=NY-1; k>=0;k--) {
+			if(worksheet->getMainWin()->speedMode()) {
+				int mod = (int) (NY/sqrt((double) worksheet->getMainWin()->speedModeValue()));
+				if(mod==0) mod=1;
+				if(k%mod != 0) continue;	// speed mode
+			}
 			for(int j=NX-1 ;j>=0;j--) {
 				int index = j+k*NX;
+				if (d[index].Masked())
+					continue;
+				
+				if(worksheet->getMainWin()->speedMode()) {
+					int mod = (int) (NX/sqrt((double) worksheet->getMainWin()->speedModeValue()));
+					if(mod==0) mod=1;
+					if(j%mod != 0) continue;	// speed mode
+				}
 				// TODO : scales (log10,log2,ln,sqrt)
-				double x = xmin + (d[index].X() - actrange[0].Min()) * (xmax-xmin)/(actrange[0].Max() - actrange[0].Min())
-					+ (xmax-xmin)/(2*(actrange[1].Max() - actrange[1].Min()))*(d[index].Y()-actrange[1].Min());
-				double y = ymax - (d[index].Y() - actrange[1].Min()) * (ymax-ymin)/(actrange[1].Max() - actrange[1].Min())
-					+ (ymax-ymin)/(2*(actrange[1].Max() - actrange[1].Min()))*(d[index].Y()-actrange[1].Min())
-					- (d[index].Z()-actrange[2].Min()) * (ymax-ymin)/(actrange[2].Max() - actrange[2].Min());
+				double x = xmin + (d[index].X() - actrange[0].rMin()) *
+					(xmax-xmin)/(actrange[0].rMax() - actrange[0].rMin())
+					+ (xmax-xmin)/(2*(actrange[1].rMax() -
+					actrange[1].rMin()))*(d[index].Y()-actrange[1].rMin());
+				double y = ymax - (d[index].Y() - actrange[1].rMin()) *
+					(ymax-ymin)/(actrange[1].rMax() - actrange[1].rMin())
+					+ (ymax-ymin)/(2*(actrange[1].rMax() -
+					actrange[1].rMin()))*(d[index].Y()-actrange[1].rMin())
+					- (d[index].Z()-actrange[2].rMin()) * (ymax-ymin)/(actrange[2].rMax()
+					  - actrange[2].rMin());
 
 				int xlen = (xmax-xmin)/(NX-1);
 				int ylen = ymax-ymin;
 				if (NY>1)
 					ylen = (ymax-ymin)/(NY-1);
 
-				int dropy = (int)(y+(d[index].Z()-actrange[2].Min()) *
-						(ymax-ymin)/(actrange[2].Max() - actrange[2].Min()));
+				int dropy = (int)(y+(d[index].Z()-actrange[2].rMin()) *
+						(ymax-ymin)/(actrange[2].rMax() - actrange[2].rMin()));
 
 				if (x >= xmin-1 && x <= xmax+(xmax-xmin)/2+1
 						&& y >= ymin-(ymax-ymin)/2-1 && y <= ymax+1) {
-					QPen pen( style.Color(), style.getWidth(),(Qt::PenStyle) style.getPenStyle() );
+					QPen pen( style->Color(), style->Width(),(Qt::PenStyle) style->PenStyle() );
 					p->setPen(pen);
 
-					if (style.isFilled()) {
+					if (style->isFilled()) {
 						QPointArray a;
-						p->setBrush(style.FillColor());
+						p->setBrush(style->FillColor());
 
 						if (type == 0) {
 //							if (k>0 && j<NX-1) {
@@ -346,7 +378,7 @@ void Plot3D::drawCurves(QPainter *p, int w, int h) {
 					if (type == 4)
 						p->drawLine((int)x,(int)y,(int)x,(int)dropy);
 
-					symbol.draw(p,(int)x,(int)y);
+					symbol->draw(p,(int)x,(int)y);
 					graph->getAnnotateValues().draw(p,(int)x,(int)y,d[index].X(),d[index].Y(),d[index].Z());
 				}
 				oldx = x;oldy = y;
@@ -361,9 +393,9 @@ void Plot3D::drawCurves(QPainter *p, int w, int h) {
 
 //! draw the axes. hide=1 : only front axes (others hidden by curves)
 void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
+	kdDebug()<<"Plot3D::drawAxes()"<<endl;
 	const int unit = 5, gap = 10, numunit = 40, numunit2 = 20;
 
-	kdDebug()<<"Plot3D::drawAxes()"<<endl;
 	int xmin = (int)(w*(size.X()*p1.X()+position.X()));
 	int xmax = (int)(w*(size.X()*p2.X()+position.X()));
 	int ymin = (int)(h*(size.Y()*p1.Y()+position.Y()));
@@ -382,21 +414,21 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 	// axes label
 	// x,x2,x3,x4
 	double xx[4] = {xmax,xmin+(xmax-xmin)/2,xmin+(xmax-xmin)/2,xmax};
-	double yx[4] = {(ymax+ymin)/2+(2*unit+numunit2)*axis[0].majorTicsEnabled(),
-		ymax+(2*unit+numunit2)*axis[3].majorTicsEnabled(),ymin-(2*unit+numunit2)*axis[6].majorTicsEnabled()-3*gap,
-		ymin-(ymax-ymin)/2-(2*unit+numunit2)*axis[9].majorTicsEnabled()-3*gap};
+	double yx[4] = {(ymax+ymin)/2+(2*unit+numunit2)*axis[0].MajorTicsEnabled(),
+		ymax+(2*unit+numunit2)*axis[3].MajorTicsEnabled(),ymin-(2*unit+numunit2)*axis[6].MajorTicsEnabled()-3*gap,
+		ymin-(ymax-ymin)/2-(2*unit+numunit2)*axis[9].MajorTicsEnabled()-3*gap};
 	for (int i=start;i<4;i++) {
 		Label *label = axis[3*i].label();
 		if (label->X()==0)	// default
 			label->setPosition((xx[i]+gap)/(double)w,yx[i]/(double)h);
 		if (axis[3*i].enabled())
-			label->draw(p,position,size,w,h);
+			label->draw(worksheet,p,position,size,w,h,0);
 	}
 
 	// z,z2,z3,z4
-	double xz[4] = {xmax-2*(xmax-xmin)/3-2*gap+axis[2].label()->font().pointSize()-gap,
-			gap+axis[5].label()->font().pointSize()-gap, xmax+(2*unit+numunit)*axis[8].majorTicsEnabled(),
-			xmax+(xmax-xmin)/2+(2*unit+numunit)*axis[11].majorTicsEnabled()};
+	double xz[4] = {xmax-2*(xmax-xmin)/3-2*gap+axis[2].label()->Font().pointSize()-gap,
+			gap+axis[5].label()->Font().pointSize()-gap, xmax+(2*unit+numunit)*axis[8].MajorTicsEnabled(),
+			xmax+(xmax-xmin)/2+(2*unit+numunit)*axis[11].MajorTicsEnabled()};
 	double yz[4] = {ymin,ymin+(ymax-ymin)/2,ymin+(ymax-ymin)/2,ymin};
 	for (int i=start;i<4;i++) {
 		Label *label = axis[3*i+2].label();
@@ -404,17 +436,17 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 		if (label->X()==0)	// default
 			label->setPosition(xz[i]/(double)w,(yz[i]-gap)/(double)h);
 		if (axis[3*i+2].enabled())
-			label->drawY(p,position,size,w,h,270);
+			label->draw(worksheet,p,position,size,w,h,270);
 		p->restore();
 	}
 
 	// y,y,2,y3,y4
 	double dx = (xmax-xmin)/2, dy = (ymax-ymin)/2;
 	double phi = 180.0/M_PI*atan(dy/dx);
-	double xy[4] = {xmin+(xmax+xmin)/4-(2*unit+numunit)*axis[1].majorTicsEnabled(),
-		xmax+(xmax+xmin)/4+(2*unit+numunit)*axis[4].majorTicsEnabled()-4*gap,
-		xmax+(xmax+xmin)/4+(2*unit+numunit)*axis[7].majorTicsEnabled()-4*gap,
-		xmin+(xmax+xmin)/4-(2*unit+numunit)*axis[10].majorTicsEnabled()
+	double xy[4] = {xmin+(xmax+xmin)/4-(2*unit+numunit)*axis[1].MajorTicsEnabled(),
+		xmax+(xmax+xmin)/4+(2*unit+numunit)*axis[4].MajorTicsEnabled()-4*gap,
+		xmax+(xmax+xmin)/4+(2*unit+numunit)*axis[7].MajorTicsEnabled()-4*gap,
+		xmin+(xmax+xmin)/4-(2*unit+numunit)*axis[10].MajorTicsEnabled()
 		};
 	double yy[4] = {ymax-(ymax-ymin)/4-4*gap,ymax-(ymax-ymin)/4+2*gap,
 		ymin-(ymax-ymin)/4+2*gap,ymin-(ymax-ymin)/4-4*gap };
@@ -424,7 +456,7 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 		if (label->X()==0)	// default
 			label->setPosition((xy[i]-2*gap)/(double)w,yy[i]/(double)h);
 		if (axis[3*i+1].enabled())
-			label->drawY(p,position,size,w,h,360-phi);
+			label->draw(worksheet,p,position,size,w,h,360-phi);
 		p->restore();
 	}
 
@@ -434,7 +466,7 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 	for (int k=start;k<4;k++) {
 		int xi[4]={(xmin+xmax)/2,xmin,xmin,(xmin+xmax)/2};
 		int yi1[4], yi2[4], ykna[4], yknb[4];
-		switch (axis[3*k].getTicsPos()) {	// major/minor tics 
+		switch (axis[3*k].TicsPos()) {	// major/minor tics 
 		case 0:
 			yi1[0]=ymax-(ymax-ymin)/2+10; yi1[1]=ymax; yi1[2]=ymin-10; yi1[3]=ymin-(ymax-ymin)/2-10;
 			yi2[0]=ymax-(ymax-ymin)/2; yi2[1]=ymax+10; yi2[2]=ymin; yi2[3]=ymin-(ymax-ymin)/2;
@@ -460,17 +492,18 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 		int yib[4]={ymax-(ymax-ymin)/2,ymax,ymax,ymin};
 		int yina[4]={ymin-(ymax-ymin)/2,ymax-(ymax-ymin)/2,ymin,ymin-(ymax-ymin)/2};
 		int yinb[4]={ymax-(ymax-ymin)/2,ymax,ymax,ymin};
-		if (axis[3*k].majorTicsEnabled() && axis[3*k].enabled()) {
-			double min = actrange[0].Min(), max = actrange[0].Max();
+		if (axis[3*k].MajorTicsEnabled() && axis[3*k].enabled()) {
+			double min = actrange[0].rMin(), max = actrange[0].rMax();
 			TScale scale = axis[k].Scale();
-			int t=0;
+			int t=-1;
 			switch (scale) {
-			case LINEAR: t = axis[3*k].majorTics(); break;
+			case LINEAR: case SX2: t = axis[3*k].MajorTics(); break;
 			case LOG10: t = (int) log10(max/min)+2; break;
 			case LOG2: t = (int) log2(max/min)+2; break;
 			case LN: t = (int) log(max/min)+2; break;
 			case SQRT: t = (int) (pow(max,2)-pow(min,2))+1; break;
 			}
+			if(t==0) t=-1;
 
 			for (int i=0;i <= t;i++) {
 				int x1=0, x2=0;
@@ -501,55 +534,58 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 					x1 = xi[k]+(int)((sqrt(min*min+i)-min)/(max-min)*(xmax-xmin));
 					x2 = xi[k]+(int)((sqrt(min*min+i+1)-min)/(max-min)*(xmax-xmin));
 					} break;
+				default: break;
 				}
 
 				int xia[4]={x1,x1+(xmax-xmin)/2,x1,x1};
 				int xib[4]={x1,x1,x1,x1-(xmax-xmin)/2};
 
 				// major tics
-				if(axis[3*k].getTicsPos()!=3) {
-					p->setPen(axis[3*k].ticsColor());
+				if(axis[3*k].TicsPos()!=3) {
+					p->setPen(QPen(axis[3*k].TicsColor(),axis[3*k].majorTicsWidth()));
 					p->drawLine(x1,yi1[k],x1,yi2[k]);
 				}
 
 				if (gridenabled[6*k]) {
-					p->setPen(Qt::DashLine);
-					p->setPen(axis[3*k].gridColor());
+					p->setPen(QPen(axis[3*k].majorGridColor(),
+						axis[3*k].majorGridWidth(),axis[3*k].MajorGridType()));
 					p->drawLine(xia[k],yia[k],xib[k],yib[k]);
 					p->setPen(Qt::SolidLine);
 				}
-				if (graphlist->getNumber() > 0) {
-					QColor c = axis[3*k].ticsLabelColor();
-					QFont f = axis[3*k].ticsFont();
-					int atlf = axis[3*k].ticsLabelFormat();
+				if (graphlist->Number() > 0) {
+					QColor c = axis[3*k].TicsLabelColor();
+					QFont f = axis[3*k].TicsFont();
+					int atlf = axis[3*k].TicsLabelFormat();
 
 					double dx = max-min;
 					double value=0;
 					switch(scale) {
-						case LINEAR: value = min + dx*(x1-xi[k])/(xmax-xmin); break;
+						case LINEAR: value = min + i*dx/t; break;
 						case LOG10: value = pow(10,ceil(log10(min)))*pow(10.0,i-1); break;
 						case LOG2: value = pow(2,ceil(log2(min)))*pow(2.0,i-1); break;
 						case LN: value = pow(M_E,ceil(log(min)))*pow(M_E,i-1); break;
-						case SQRT: value = min + dx*(x1-xi[k])/(xmax-xmin); break;
+						case SQRT: value = min + i*dx/t; break;
+						default: break;
 					}
 
 					// scale and shift value
-					value = value*axis[3*k].getScaling()+axis[3*k].getShift();
+					value = value*axis[3*k].Scaling()+axis[3*k].Shift();
 
-					QString label = getTicLabel(3*k,atlf,axis[3*k].ticsLabelPrecision(), 
-						axis[3*k].getDateTimeFormat(),value);
+					QString label = TicLabel(atlf,axis[3*k].TicsLabelPrecision(), 
+						axis[3*k].DateTimeFormat(),value);
 						
 					// apply prefix & suffix
-					label.prepend(axis[3*k].getTicLabelPrefix());
-					label.append(axis[3*k].getTicLabelSuffix());
+					label.prepend(axis[3*k].TicsLabelPrefix());
+					label.append(axis[3*k].TicsLabelSuffix());
 
 					// draw tic label
 					QFontMetrics fm(f);
 					p->save();
-					int yilb[4]={ymax-(ymax-ymin)/2+fm.ascent()+15,ymax+fm.ascent()+15,
-						ymin-20,ymin-(ymax-ymin)/2-20};
+					int tlg = axis[3*k].TicsLabelGap();
+					int yilb[4]={ymax-(ymax-ymin)/2+fm.ascent()+tlg,ymax+fm.ascent()+tlg,
+						ymin-tlg,ymin-(ymax-ymin)/2-tlg};
 					p->translate(x1,yilb[k]);
-					p->rotate(axis[3*k].getTicsLabelRotation());
+					p->rotate(axis[3*k].TicsLabelRotation());
 					if (atlf == AUTO || atlf == NORMAL || atlf == SCIENTIFIC) {
 						p->setPen(c);
 						f.setPointSize((int)(f.pointSize()*size.X()));	// resize tic label
@@ -559,22 +595,24 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 					}
 					else {	// rich text label
 						QSimpleRichText *richtext = new QSimpleRichText(label,f);
-						richtext->draw(p,-richtext->width()/4, -fm.ascent()/2,QRect(),QColorGroup());
+						QColorGroup cg;
+						cg.setColor(QColorGroup::Text,c);
+						richtext->draw(p,-richtext->width()/4, -fm.ascent()/2,QRect(),cg);
 					}
 					p->restore();
 				}
-				if (axis[3*k].minorTicsEnabled() && i != t ) {
-					for (int j=1;j <= axis[3*k].minorTics()+1;j++) {
-						int x = x1+j*(x2-x1)/(axis[3*k].minorTics()+1);
+				if (axis[3*k].MinorTicsEnabled() && i != t ) {
+					for (int j=1;j <= axis[3*k].MinorTics()+1;j++) {
+						int x = x1+j*(x2-x1)/(axis[3*k].MinorTics()+1);
 						int xina[4]={x,x+(xmax-xmin)/2,x,x};
 						int xinb[4]={x,x,x,x-(xmax-xmin)/2};
-						if(axis[3*k].getTicsPos()!=3) {
-							p->setPen(axis[3*k].ticsColor());
+						if(axis[3*k].TicsPos()!=3) {
+							p->setPen(QPen(axis[3*k].TicsColor(),axis[3*k].minorTicsWidth()));
 							p->drawLine(x,ykna[k],x,yknb[k]);
 						}
-						if (gridenabled[6*k+1]) {
-							p->setPen(Qt::DotLine);
-							p->setPen(axis[3*k].gridColor());
+						if (gridenabled[6*k+1] && j != axis[3*k].MinorTics()+1 ) {
+							p->setPen(QPen(axis[3*k].minorGridColor(),
+								axis[3*k].minorGridWidth(),axis[3*k].MinorGridType()));
 							p->drawLine(xina[k],yina[k],xinb[k],yinb[k]);
 							p->setPen(Qt::SolidLine);
 						}
@@ -588,7 +626,7 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 	for (int k=start;k<4;k++) {
 		int yi[4]={ymin-(ymax-ymin)/2,ymin,ymin,ymin-(ymax-ymin)/2};
 		int xi1[4], xi2[4], xkna[4], xknb[4];
-		switch (axis[3*k+2].getTicsPos()) {
+		switch (axis[3*k+2].TicsPos()) {
 		case 0:
 			//major tics
 			xi1[0]=(xmax+xmin)/2; xi1[1]=xmin-10; xi1[2]=xmax; xi1[3]=xmax+(xmax-xmin)/2;
@@ -618,50 +656,72 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 		int xib[4]={(xmax+xmin)/2,xmax,xmax,xmax+(xmax-xmin)/2};
 		int xina[4]={xmin,xmin,xmax,(xmax+xmin)/2};
 		int xinb[4]={(xmax+xmin)/2,xmax,xmax+(xmax-xmin)/2,xmax+(xmax-xmin)/2};
-		int yk[4]={ymax-(ymax-ymin)/2,ymax,ymax,ymax-(ymax-ymin)/2};
-		if (axis[3*k+2].majorTicsEnabled() && axis[3*k+2].enabled()) {
-			int t = axis[3*k+2].majorTics();
+		
+		if (axis[3*k+2].MajorTicsEnabled() && axis[3*k+2].enabled()) {
+			double min = actrange[2].rMin(), max = actrange[2].rMax();
+			TScale scale = axis[k].Scale();
+			int t=-1;
+			switch (scale) {
+			case LINEAR: t = axis[3*k+2].MajorTics(); break;
+			case LOG10: t = (int) log10(max/min)+2; break;
+			case LOG2: t = (int) log2(max/min)+2; break;
+			case LN: t = (int) log(max/min)+2; break;
+			case SQRT: t = (int) (pow(max,2)-pow(min,2))+1; break;
+			default: break;
+			}
+			if(t==0) t=-1;
+			
 			for (int i=0;i <= t;i++) {
+				// TODO : use scale (see x)
 				int y1 = yi[k]+i*(ymax-ymin)/t;
 				int y2 = yi[k]+(i+1)*(ymax-ymin)/t;
 				int yia[4] = {ymin+i*(ymax-ymin)/t,y1,y1+(ymin-ymax)/2,y1};
 			
-				if (axis[3*k+2].getTicsPos()!=3) {
-					p->setPen(axis[3*k+2].ticsColor());
+				if (axis[3*k+2].TicsPos()!=3) {
+					p->setPen(QPen(axis[3*k+2].TicsColor(),axis[3*k+2].majorTicsWidth()));
 					p->drawLine(xi1[k],y1,xi2[k],y1);
 				}
 				
 				if (gridenabled[6*k+4]) {
-					p->setPen(Qt::DashLine);
-					p->setPen(axis[3*k+2].gridColor());
+					p->setPen(QPen(axis[3*k+2].majorGridColor(),
+						axis[3*k+2].majorGridWidth(),axis[3*k+2].MajorGridType()));
 					p->drawLine(xia[k],yia[k],xib[k],y1);
 					p->setPen(Qt::SolidLine);
 				}
-				if (graphlist->getNumber() > 0) {
-					QColor c = axis[3*k+2].ticsLabelColor();
-					QFont f = axis[3*k+2].ticsFont();
-					double dz = actrange[2].Max()-actrange[2].Min();
-					double value = actrange[2].Min() + dz*(yk[k]-y1)/(ymax-ymin);
-					int atlf = axis[3*k+2].ticsLabelFormat();
+				if (graphlist->Number() > 0) {
+					QColor c = axis[3*k+2].TicsLabelColor();
+					QFont f = axis[3*k+2].TicsFont();
+					double dz = max-min;
+					int atlf = axis[3*k+2].TicsLabelFormat();
 	
+					double value=0;
+					switch(scale) {
+						case LINEAR: value = min + (t-i)*dz/t; break;
+						case LOG10: value = pow(10,ceil(log10(min)))*pow(10.0,i-1); break;
+						case LOG2: value = pow(2,ceil(log2(min)))*pow(2.0,i-1); break;
+						case LN: value = pow(M_E,ceil(log(min)))*pow(M_E,i-1); break;
+						case SQRT: value = min + (t-i)*dz/t; break;
+						default: break;
+					}
 					// scale and shift value
-					value = value*axis[3*k+2].getScaling()+axis[3*k+2].getShift();
+					value = value*axis[3*k+2].Scaling()+axis[3*k+2].Shift();
 	
-					QString label = getTicLabel(3*k+2,atlf,axis[3*k+2].ticsLabelPrecision(),
-							axis[3*k+2].getDateTimeFormat(),value);
+					QString label = TicLabel(atlf,axis[3*k+2].TicsLabelPrecision(),
+							axis[3*k+2].DateTimeFormat(),value);
 
 					// apply prefix & suffix
-					label.prepend(axis[3*k+2].getTicLabelPrefix());
-					label.append(axis[3*k+2].getTicLabelSuffix());
+					label.prepend(axis[3*k+2].TicsLabelPrefix());
+					label.append(axis[3*k+2].TicsLabelSuffix());
 
 					// draw tic label
 					QFontMetrics fm(f);
 					p->save();
+					int tlg = axis[3*k+2].TicsLabelGap();
 					if (atlf == AUTO || atlf == NORMAL || atlf == SCIENTIFIC) {
-						int xk[4]={(xmax+xmin)/2-fm.width(label)/2-15,xmin-fm.width(label)/2-15,
-							xmax+20,xmax+(xmax-xmin)/2+20};
+						int xk[4]={(xmax+xmin)/2-fm.width(label)/2-tlg,xmin-fm.width(label)/2-tlg,
+							xmax+tlg,xmax+(xmax-xmin)/2+tlg};
 						p->translate(xk[k],y1);
-						p->rotate(axis[3*k+2].getTicsLabelRotation());
+						p->rotate(axis[3*k+2].TicsLabelRotation());
 						p->setPen(c);
 						f.setPointSize((int)(f.pointSize()*size.X()));	// resize tic label
 						p->setFont(f);
@@ -670,26 +730,28 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 					}
 					else {	// rich text label
 						QSimpleRichText *richtext = new QSimpleRichText(label,f);
-						int xk[4]={(xmax+xmin)/2-richtext->width()/2-15,xmin-richtext->width()-15,
-							xmax+20,xmax+(xmax-xmin)/2+20};
+						int xk[4]={(xmax+xmin)/2-richtext->width()/2-tlg,xmin-richtext->width()-tlg,
+							xmax+tlg,xmax+(xmax-xmin)/2+tlg};
 						p->translate(xk[k],y1);
-						p->rotate(axis[3*k+2].getTicsLabelRotation());
-						richtext->draw(p,-richtext->width()/2, -fm.ascent()/2,QRect(),QColorGroup());
+						p->rotate(axis[3*k+2].TicsLabelRotation());
+						QColorGroup cg;
+						cg.setColor(QColorGroup::Text,c);
+						richtext->draw(p,-richtext->width()/2, -fm.ascent()/2,QRect(),cg);
 					}
 					p->restore();
 				}
-				if (axis[3*k+2].minorTicsEnabled() && i != t ) {
-					for (int j=1;j <= axis[3*k+2].minorTics()+1;j++) {
-						int y = y1+j*(y2-y1)/(axis[3*k+2].minorTics()+1);
+				if (axis[3*k+2].MinorTicsEnabled() && i != t ) {
+					for (int j=1;j <= axis[3*k+2].MinorTics()+1;j++) {
+						int y = y1+j*(y2-y1)/(axis[3*k+2].MinorTics()+1);
 						int yina[4]={y+(ymax-ymin)/2,y,y,y};
 						int yinb[4]={y,y,y+(ymin-ymax)/2,y};
-						if(axis[3*k+2].getTicsPos()!=3) {
-							p->setPen(axis[3*k+2].ticsColor());
+						if(axis[3*k+2].TicsPos()!=3) {
+							p->setPen(QPen(axis[3*k+2].TicsColor(),axis[3*k+2].minorTicsWidth()));
 							p->drawLine(xkna[k],y,xknb[k],y);
 						}
-						if (gridenabled[6*k+5]) {
-							p->setPen(Qt::DotLine);
-							p->setPen(axis[3*k+2].gridColor());
+						if (gridenabled[6*k+5] && j != axis[3*k+2].MinorTics()+1 ) {
+							p->setPen(QPen(axis[3*k+2].minorGridColor(),
+								axis[3*k+2].minorGridWidth(),axis[3*k+2].MinorGridType()));
 							p->drawLine(xina[k],yina[k],xinb[k],yinb[k]);
 							p->setPen(Qt::SolidLine);
 						}
@@ -703,16 +765,29 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 	for (int k=start;k<4;k++) {
 		int xi[4]={xmin,xmax,xmax,xmin};
 		int yi[4]={ymax,ymax,ymin,ymin};
-		if (axis[3*k+1].majorTicsEnabled() && axis[3*k+1].enabled()) { 		// y
-			int t = axis[3*k+1].majorTics();
+		if (axis[3*k+1].MajorTicsEnabled() && axis[3*k+1].enabled()) { 		// y
+			double min = actrange[1].rMin(), max = actrange[1].rMax();
+			TScale scale = axis[k].Scale();
+			int t=-1;
+			switch (scale) {
+			case LINEAR: t = axis[3*k+1].MajorTics(); break;
+			case LOG10: t = (int) log10(max/min)+2; break;
+			case LOG2: t = (int) log2(max/min)+2; break;
+			case LN: t = (int) log(max/min)+2; break;
+			case SQRT: t = (int) (pow(max,2)-pow(min,2))+1; break;
+			default: break;
+			}
+			if (t==0) t=-1;
+			
 			for (int i=0;i <= t;i++) {
+				// TODO : use scale (see x)
 				int y1 = yi[k]-i*(ymax-ymin)/(2*t);
 				int y2 = yi[k]-(i+1)*(ymax-ymin)/(2*t);
 				int x1 = xi[k]+i*(xmax-xmin)/(2*t);
 				int x2 = xi[k]+(i+1)*(xmax-xmin)/(2*t);
 
 				int xi1[4],xi2[4];
-				switch(axis[3*k+1].getTicsPos()) {
+				switch(axis[3*k+1].TicsPos()) {
 				case 0:
 					xi1[0]=xi1[1]=xi1[2]=xi1[3]=x1;
 					xi2[0]=xi2[3]=x1-10;xi2[1]=xi2[2]=x1+10;
@@ -730,42 +805,45 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 				int xib[4]={x1+xmax-xmin,x1,x1,x1};
 				int yib[4]={y1,y1-ymax+ymin,y1,y1+ymax-ymin};
 				
-				if (axis[3*k+1].getTicsPos()!=3) {
-					p->setPen(axis[3*k+1].ticsColor());
+				if (axis[3*k+1].TicsPos()!=3) {
+					p->setPen(QPen(axis[3*k+1].TicsColor(),axis[3*k+1].majorTicsWidth()));
 					p->drawLine(xi1[k],y1,xi2[k],y1);
 				}
 				
 				if (gridenabled[6*k+2]) {
-					p->setPen(Qt::DashLine);
-					p->setPen(axis[3*k+1].gridColor());
+					p->setPen(QPen(axis[3*k+1].majorGridColor(),
+						axis[3*k+1].majorGridWidth(),axis[3*k+1].MajorGridType()));
 					p->drawLine(xia[k],y1,xib[k],yib[k]);
 					p->setPen(Qt::SolidLine);
 				}
-				if (graphlist->getNumber() > 0) {
-					QColor c = axis[3*k+1].ticsLabelColor();
-					QFont f = axis[3*k+1].ticsFont();
-					double dy = actrange[1].Max()-actrange[1].Min();
+				if (graphlist->Number() > 0) {
+					QColor c = axis[3*k+1].TicsLabelColor();
+					QFont f = axis[3*k+1].TicsFont();
+					double dy = max-min;
 					int yy[4]={ymax,ymax,ymin,ymin};
-					double value = actrange[1].Min()+2*dy*(yy[k]-y1)/(ymax-ymin);
-					int atlf = axis[3*k+1].ticsLabelFormat();
+					// TODO : use scale (see x)
+					// TODO : fix rounding bug
+					double value = min+2*dy*(yy[k]-y1)/(ymax-ymin);
+					int atlf = axis[3*k+1].TicsLabelFormat();
 
 					// scale and shift value
-					value = value*axis[3*k+1].getScaling()+axis[3*k+1].getShift();
+					value = value*axis[3*k+1].Scaling()+axis[3*k+1].Shift();
 
-					QString label = getTicLabel(3*k+1,atlf,axis[3*k+1].ticsLabelPrecision(),
-							axis[3*k+1].getDateTimeFormat(),value);
+					QString label = TicLabel(atlf,axis[3*k+1].TicsLabelPrecision(),
+							axis[3*k+1].DateTimeFormat(),value);
 
 					// apply prefix & suffix
-					label.prepend(axis[3*k+1].getTicLabelPrefix());
-					label.append(axis[3*k+1].getTicLabelSuffix());
+					label.prepend(axis[3*k+1].TicsLabelPrefix());
+					label.append(axis[3*k+1].TicsLabelSuffix());
 
 					// draw tic label
 					QFontMetrics fm(f);
 					p->save();
+					int tlg = axis[3*k+1].TicsLabelGap();
 					if (atlf == AUTO || atlf == NORMAL || atlf == SCIENTIFIC) {
-						int xilb[4]={x1-fm.width(label)/2-20,x1+20,x1+20,x1-fm.width(label)/2-20};
+						int xilb[4]={x1-fm.width(label)/2-tlg,x1+tlg,x1+tlg,x1-fm.width(label)/2-tlg};
 						p->translate(xilb[k],y1);
-						p->rotate(axis[3*k+1].getTicsLabelRotation());
+						p->rotate(axis[3*k+1].TicsLabelRotation());
 						p->setPen(c);
 						f.setPointSize((int)(f.pointSize()*size.X()));	// resize tic label
 						p->setFont(f);
@@ -774,24 +852,26 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 					}
 					else {	// rich text label
 						QSimpleRichText *richtext = new QSimpleRichText(label,f);
-						int xilb[4]={x1-richtext->width()/2-20,x1+20,x1+20,x1-richtext->width()/2-20};
+						int xilb[4]={x1-richtext->width()/2-tlg,x1+tlg,x1+tlg,x1-richtext->width()/2-tlg};
 						p->translate(xilb[k],y1);
-						p->rotate(axis[3*k+1].getTicsLabelRotation());
-						richtext->draw(p,-richtext->width()/2, -fm.ascent()/2,QRect(),QColorGroup());
+						p->rotate(axis[3*k+1].TicsLabelRotation());
+						QColorGroup cg;
+						cg.setColor(QColorGroup::Text,c);
+						richtext->draw(p,-richtext->width()/2, -fm.ascent()/2,QRect(),cg);
 					}
 					p->restore();
 				}
-				if (axis[3*k+1].minorTicsEnabled() && i != t ) {
-					for (int j=1;j <= axis[3*k+1].minorTics()+1;j++) {
-						int y = y1+j*(y2-y1)/(axis[3*k+1].minorTics()+1);
-						int x = x1+j*(x2-x1)/(axis[3*k+1].minorTics()+1);
-						p->setPen(axis[3*k+1].ticsColor());
+				if (axis[3*k+1].MinorTicsEnabled() && i != t ) {
+					for (int j=1;j <= axis[3*k+1].MinorTics()+1;j++) {
+						int y = y1+j*(y2-y1)/(axis[3*k+1].MinorTics()+1);
+						int x = x1+j*(x2-x1)/(axis[3*k+1].MinorTics()+1);
+						p->setPen(QPen(axis[3*k+1].TicsColor(),axis[3*k+1].minorTicsWidth()));
 						int xina[4]={x,x,x-(xmax-xmin),x};
 						int xinb[4]={x+xmax-xmin,x,x,x};
 						int yinb[4]={y,y-ymax+ymin,y,y+ymax-ymin};
 					
 						int xkna[4],xknb[4];
-						switch(axis[3*k+1].getTicsPos()) {
+						switch(axis[3*k+1].TicsPos()) {
 						case 0:
 							xkna[0]=xkna[1]=xkna[2]=xkna[3]=x;
 							xknb[0]=xknb[3]=x-5;xknb[1]=xknb[2]=x+5;
@@ -806,13 +886,13 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 							break;
 						}
 					
-						if (axis[3*k+1].getTicsPos()!=3) {
+						if (axis[3*k+1].TicsPos()!=3) {
 							p->drawLine(xkna[k],y,xknb[k],y);
 						}
-						if (gridenabled[6*k+3]) {
-							p->setPen(Qt::DotLine);
-							p->setPen(axis[3*k+1].gridColor());
-							p->drawLine(xina[k],y,xinb[k],yinb[k]);
+						if (gridenabled[6*k+3] && j != axis[3*k+1].MinorTics()+1 ) {
+							p->setPen(QPen(axis[3*k+1].minorGridColor(),
+								axis[3*k+1].minorGridWidth(),axis[3*k+1].MinorGridType()));
+ 								p->drawLine(xina[k],y,xinb[k],yinb[k]);
 							p->setPen(Qt::SolidLine);
 						}
 					}
