@@ -10,18 +10,19 @@ public:
 	PlotPie(Worksheet *p);
 	~PlotPie() {}
 	QStringList Info();
-	Axis *getAxis(int i) { return 0; }
-	void saveAxes(QTextStream *t) {}
-	void openAxes(QTextStream *t,int version) {}
-	void enableGrid(int index,bool b) { }
-	bool gridEnabled(int index) { return false; }
-	void enableBorder(int index,bool b) { }
-	bool borderEnabled(int index) { return false; }
+	Axis *getAxis(int) { return 0; }
+	void saveAxes(QTextStream *) {}
+	void openAxes(QTextStream *, int) {}
+	void enableGrid(int, bool) {}
+	bool gridEnabled(int) { return false; }
+	void enableBorder(int, bool) {}
+	bool borderEnabled(int) { return false; }
 	void draw(QPainter* p,int w, int h);
-/*	void drawBorder(QPainter* p,bool hide);*/
 	void drawCurves(QPainter* p, int w, int h);
 /*	void drawAxes(QPainter* p,bool hide);*/
-	void setBorder(int item, bool on) {}
+	void setBorder(int, bool) { }
+	void setRange(LRange* r,int i) {range[i]=*r; }
+	void setActRange(LRange* r,int i) {actrange[i]=*r; }
 	void setRanges(LRange* r) {range[0]=r[0];range[1]=r[1];range[2]=r[2];}
 	void setActRanges(LRange* r) {actrange[0]=r[0];actrange[1]=r[1];actrange[2]=r[2];}
 private:
