@@ -13,15 +13,16 @@ public:
 	Axis *getAxis(int i) { return &axis[i]; }
 	void saveAxes(QTextStream *t);
 	void openAxes(QTextStream *t,int version);
-	void enableGrid(int index,bool b) { gridenabled[index]=b; }
+	void enableGrid(int index,bool b=true) { gridenabled[index]=b; }
 	bool gridEnabled(int index) { return gridenabled[index]; }
-	void enableBorder(int index,bool b) { }	// TODO
-	bool borderEnabled(int index) { return false; }	// TODO
+	void enableBorder(int, bool) {}	// TODO
+	bool borderEnabled(int) { return false; }	// TODO
 	void draw(QPainter* p,int w, int h);
-/*	void drawBorder(QPainter* p,bool hide);*/
 	void drawCurves(QPainter* p, int w, int h);
 /*	void drawAxes(QPainter* p,bool hide);*/
-	void setBorder(int item, bool on) {}
+	void setBorder(int, bool) {}
+	void setRange(LRange* r,int i) {range[i]=*r;}
+	void setActRange(LRange* r,int i) {actrange[i]=*r;}
 	void setRanges(LRange* r) {range[0]=r[0];range[1]=r[1];}
 	void setActRanges(LRange* r) {actrange[0]=r[0];actrange[1]=r[1];}
 private:
