@@ -9,12 +9,13 @@ class PruneListDialog : public ListDialog
 {
 	Q_OBJECT
 public:
-	PruneListDialog(Worksheet *p, const char *name);
-private slots:
-	void ok_clicked() { apply_clicked(); accept(); }
-	void apply_clicked();
+	PruneListDialog(MainWin *mw, const char *name);
+public slots:
+	void setNumber(int n) { nle->setText(QString::number(n)); }	//!< set number of points to prune
 private:
 	KLineEdit *nle;
+private slots:
+	int apply_clicked();
 };
 
 #endif // PRUNELISTDIALOG_H
