@@ -17,9 +17,9 @@ class RichTextWidget: public QWidget
 {
 	Q_OBJECT
 public:
-	RichTextWidget(QWidget *parent, Label *label, const char *name);
+	RichTextWidget(QWidget *parent, Label *label, const char *name, bool qwtplot=0);
 public slots:
-	void setLabel(Label *label) { l = label;update(); }
+	void setLabel(Label *label) { l = label; update(); }
 	Label* label() { apply(); return l; }
 	void update();
 private slots:
@@ -37,11 +37,11 @@ private:
 	void apply();
 	Label *l;
 	QTextEdit *te;
-	KLineEdit *xle, *yle, *titleFont;
+	KLineEdit *xle, *yle, *titleFont, *rotle;
 	QToolButton *bold, *italic, *underline, *superscript, *subscript;
 	KPopupMenu *sgletters, *bgletters, *oletters;
 	KColorButton *kcb;
-	QCheckBox *boxedcb;
+	QCheckBox *boxedcb, *texcb;
 };
 
 #endif //RICHTEXTWIDGET_H
