@@ -9,12 +9,13 @@ class SmoothListDialog : public ListDialog
 {
 	Q_OBJECT
 public:
-	SmoothListDialog(Worksheet *p, const char *name);
-private slots:
-	void ok_clicked() { apply_clicked(); accept(); }
-	void apply_clicked();
+	SmoothListDialog(MainWin *mw, const char *name);
+public slots:
+	void setNumber(int n) {nle->setText(QString::number(n)); }	//!< set number to smooth
 private:
 	KLineEdit *nle;
+private slots:
+	int apply_clicked();
 };
 
 #endif // SMOOTHLISTDIALOG_H
