@@ -1,4 +1,7 @@
-//LabPlot : Style.cc
+//LabPlot : Style.h
+
+#ifndef STYLE_H
+#define STYLE_H
 
 #include <qcolor.h>
 
@@ -12,18 +15,24 @@ public:
 	void setType(int t) { type = t; }
 	QColor Color() { return color; }
 	void setColor(QString c) { color = QColor(c); }
-	int getWidth() { return width; }
+	void setColor(QColor c) { color = c; }
+	int Width() { return width; }
 	void setWidth(int w) { width = w; }
-	int getPenStyle() { return penStyle; }
+	int PenStyle() { return penStyle; }
 	void setPenStyle(int p) { penStyle = p; }
-	int getBrush() { return brush; }
+	int Brush() { return brush; }
 	void setBrush (int b) { brush = b; }
 	bool isFilled() { return fill; }
 	void setFilled(int f) { fill = f; }
 	QColor FillColor() { return fillcolor; }
 	void setFillColor(QString c) { fillcolor = QColor(c); }
+	void setFillColor(QColor c) { fillcolor = c; }
+	int BoxWidth() { return boxwidth; }
+	void setBoxWidth(int b) { boxwidth = b; }
+	bool AutoBoxWidth() { return autoboxwidth; }
+	void setAutoBoxWidth(bool b=true) { autoboxwidth = b; }
 private:
-	int type;		// type : line,noline,steps,boxes,impulses
+	int type;		// type : line,noline,steps,boxes,impulses,yboxes
 	QColor color;		// line color
 	int width;		// line width
 	bool fill;		// filled to baseline
@@ -31,4 +40,8 @@ private:
 	int penStyle;		// pen style :NoPen, SolidLine, DashLine, DotLine, DashDotLine, DashDotDotLine
 	int brush;		// fill brush : NoBrush, Solid, Dense1, Dense2, Dense3, Dense4, Dense5,
 				//	 Dense6, Dense7, Horizontal, Vertical, Cross, BDiag, FDiag, DiagCross
+	int boxwidth;		// width for type boxes
+	bool autoboxwidth;	// automatic box width
 };
+
+#endif // STYLE_H
