@@ -4,7 +4,7 @@
 #define SYMBOL_H
 
 #include <qcolor.h>
-#include "defs.h"
+#include "symbols.h"
 
 class Symbol {
 public:
@@ -12,17 +12,19 @@ public:
 	void save(QTextStream *t);
 	void open(QTextStream *t,int version);
 	void draw(QPainter *p,int X, int Y);
-	SType getType() { return type; }
-	void setType(int t) { type = (SType) t; }
-	QColor getColor() { return color; }
+	SType Type() { return type; }
+	void setType(SType t) { type = t; }
+	QColor Color() { return color; }
 	void setColor(QString c) {color = QColor(c); }
-	int getSize() { return size; }
+	void setColor(QColor c) {color = c; }
+	int Size() { return size; }
 	void setSize(int s) { size = s; }
-	FType getFill() { return fill; }
+	FType Fill() { return fill; }
 	void setFill(FType f) { fill = f; }
-	QColor getFillColor() { return fillcolor; }
+	QColor FillColor() { return fillcolor; }
 	void setFillColor(QString fc) { fillcolor = QColor(fc); }
-	int getBrush() { return brush;}
+	void setFillColor(QColor fc) { fillcolor = fc; }
+	int Brush() { return brush;}
 	void setBrush(int b) { brush = b; }
 private:
 	SType type;
